@@ -22,6 +22,10 @@
 //!    module to implement TLS via [tokio-rustls](https://crates.io/crates/tokio-rustls)
 //!    and uses native system certificates found with
 //!    [rustls-native-certs](https://github.com/rustls/rustls-native-certs).
+//!  * `tokio-rustls-platform-verifier`: Enables the additional functions in the `tokio`
+//!    module to implement TLS via [tokio-rustls](https://crates.io/crates/tokio-rustls)
+//!    and uses native system certificates via the platform verifier found with
+//!    [rustls-platform-verifier](https://github.com/rustls/rustls-platform-verifier).
 //!  * `tokio-rustls-webpki-roots`: Enables the additional functions in the `tokio`
 //!    module to implement TLS via [tokio-rustls](https://crates.io/crates/tokio-rustls)
 //!    and uses the certificates [webpki-roots](https://github.com/rustls/webpki-roots)
@@ -53,6 +57,7 @@ mod handshake;
     feature = "tokio-native-tls",
     feature = "tokio-rustls-manual-roots",
     feature = "tokio-rustls-native-certs",
+    feature = "tokio-rustls-platform-verifier",
     feature = "tokio-rustls-webpki-roots",
     feature = "tokio-openssl",
 ))]
